@@ -739,13 +739,14 @@ class DictMethodEntryHelper(object):
                     epObj.setValue(self.__commonU.filterEntityPolyType(pTypeL[ii]), atName, ii)
             #
             # Add any branched entity types to the type list -
-            if dataContainer.exists("entity_branch"):
-                ebObj = dataContainer.getObj("entity_branch")
+            if dataContainer.exists("pdbx_entity_branch"):
+                ebObj = dataContainer.getObj("pdbx_entity_branch")
                 pTypeL.extend(ebObj.getAttributeValueList("type"))
             #
             polymerCompClass, ptClass, naClass, eptD = self.__commonU.getPolymerComposition(pTypeL)
+            if eptD and len(eptD) > 2:
+                logger.info("%s entity type count=%d class=%s typeD %r", dataContainer.getName(), len(eptD), polymerCompClass, eptD)
             #
-
             cObj.setValue(polymerCompClass, "polymer_composition", 0)
             cObj.setValue(ptClass, "selected_polymer_entity_types", 0)
             cObj.setValue(naClass, "na_polymer_entity_types", 0)
